@@ -7,7 +7,7 @@ class ExternalIssueReferenceV1ResponseBodyProvider(str, Enum):
     JIRA = "jira"
     JIRA_SERVER = "jira_server"
     GITHUB = "github"
-    CLUBHOUSE = "clubhouse"
+    SHORTCUT = "shortcut"
 
     def __str__(self) -> str:
         return str(self.value)
