@@ -13,14 +13,15 @@ T = TypeVar("T", bound="IncidentTypesV1ListResponseBody")
 class IncidentTypesV1ListResponseBody:
     """
     Example:
-        {'incident_types': [{'created_at': '2021-08-17T13:28:57.801578Z', 'description': 'Customer facing production
-            outages', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'is_default': False, 'name': 'Production Outage',
-            'private_incidents_only': False, 'updated_at': '2021-08-17T13:28:57.801578Z'}]}
+        {'incident_types': [{'create_in_triage': 'always', 'created_at': '2021-08-17T13:28:57.801578Z', 'description':
+            'Customer facing production outages', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'is_default': False, 'name':
+            'Production Outage', 'private_incidents_only': False, 'updated_at': '2021-08-17T13:28:57.801578Z'}]}
 
     Attributes:
-        incident_types (List['IncidentTypeV1ResponseBody']):  Example: [{'created_at': '2021-08-17T13:28:57.801578Z',
-            'description': 'Customer facing production outages', 'id': '01FCNDV6P870EA6S7TK1DSYDG0', 'is_default': False,
-            'name': 'Production Outage', 'private_incidents_only': False, 'updated_at': '2021-08-17T13:28:57.801578Z'}].
+        incident_types (List['IncidentTypeV1ResponseBody']):  Example: [{'create_in_triage': 'always', 'created_at':
+            '2021-08-17T13:28:57.801578Z', 'description': 'Customer facing production outages', 'id':
+            '01FCNDV6P870EA6S7TK1DSYDG0', 'is_default': False, 'name': 'Production Outage', 'private_incidents_only': False,
+            'updated_at': '2021-08-17T13:28:57.801578Z'}].
     """
 
     incident_types: List["IncidentTypeV1ResponseBody"]
